==> qtjambi-opengl-debuginfo-macos-6.6.0.jar: sources/QtJambiOpenGL/QOpenGLShaderProgram_shell.h <==
#ifndef QOPENGLSHADERPROGRAM_SHELL_H
#define QOPENGLSHADERPROGRAM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtOpenGL/qopenglshaderprogram.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qcolor.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qopenglcontext.h>
#include <QtGui/qtransform.h>
#include <QtGui/qvectornd.h>
#include <QtJambiGui/hashes.h>
#include <QtJambi/RegistryAPI>


class QOpenGLShaderProgram_shell : public QOpenGLShaderProgram, public QtJambiShellInterface
{
public:
    QOpenGLShaderProgram_shell(QObject* parent0 = nullptr);
    ~QOpenGLShaderProgram_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool link() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLShaderProgram_access : public QOpenGLShaderProgram
{
    jboolean __qt_link(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QOPENGLSHADERPROGRAM_SHELL_H

==> qtjambi-opengl-debuginfo-macos-6.9.3.jar: sources/QtJambiOpenGL/QOpenGLShaderProgram_shell.h <==
#ifndef QOPENGLSHADERPROGRAM_SHELL_H
#define QOPENGLSHADERPROGRAM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtOpenGL/qopenglshaderprogram.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qcolor.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qopenglcontext.h>
#include <QtGui/qtransform.h>
#include <QtGui/qvectornd.h>
#include <QtJambiGui/hashes.h>
#include <QtJambi/RegistryAPI>


class QOpenGLShaderProgram_shell : public QOpenGLShaderProgram, public QtJambiShellInterface
{
public:
    QOpenGLShaderProgram_shell(QObject* parent0 = nullptr);
    ~QOpenGLShaderProgram_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QOpenGLShaderProgram_mshell;
    friend class QOpenGLShaderProgram_oshell;
};


class QOpenGLShaderProgram_mshell : public QOpenGLShaderProgram_shell
{
public:
    using QOpenGLShaderProgram_shell::QOpenGLShaderProgram_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QOpenGLShaderProgram_oshell : public QOpenGLShaderProgram_mshell
{
public:
    using QOpenGLShaderProgram_mshell::QOpenGLShaderProgram_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool link() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLShaderProgram_access : public QOpenGLShaderProgram
{
    jboolean __qt_link(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QOPENGLSHADERPROGRAM_SHELL_H
